.. _base:

****************************
Base (`baseband_tasks.base`)
****************************

`~baseband_tasks.base` contains the base classes and functions used by other
tasks.

.. _base_api:

Reference/API
=============

.. automodapi:: baseband_tasks.base
   :no-inherited-members: